library(shiny)

tab <- read.table("vyjmenovana_slova.txt", header = TRUE,
                  sep = "\t", fileEncoding = "UTF-8-BOM", stringsAsFactors = FALSE)

ui <- fluidPage(

    titlePanel("Vyjmenovaná slova"),

    sidebarLayout(
        sidebarPanel(
           textOutput("zadani"),
           textInput("odpoved", label = "Zadejte odpověď"),
           actionButton("vyhodnot", label = "Vyhodnoť")
        ),

        mainPanel(
           textOutput("vyhodnoceni")
        )
    )
)


server <- function(input, output, session) { # trik: navíc session, aby šlo mazat vstupní políčka, viz dále...
    rv <- reactiveValues()   # zatím prázdný seznam (list) reaktivních proměnných
    rv$hodnoceni <- "Zadejte svou odpověď."   # vytváříme reaktivní proměnnou
        
    # první náhodná otázka (run once per user)
    radek <- sample(1: nrow(tab), size = 1)  # náhodný řádek tabulky
    rv$otazka <- tab$otázka[radek]           # uložíme si otázku - do reaktivní proměnné, protože se otázka má zobrazovat
    spravnaOdpoved <- tab$odpověď[radek]     # a rovnou i správnou odpověď
    
    observe({   # Pozorovací funkce, která se zavolá, když se změní cokoliv reaktivního uvnitř. Ale observe() samo o sobě nikdy nic nerenderuje (což je přesně to, co zde potřebujeme)
        input$vyhodnot  # sledujeme stisk tlačítka
        
        odp <- isolate(input$odpoved)  # výslovně nechceme reagovat na průběžně změny v políčku "odpoved"
        
        if (odp == "") {  # není nic zadáno - např. situace hned po spuštění aplikace
            return()  # nic nedělat
        } else if (odp == spravnaOdpoved) {   # trefil se
            rv$hodnoceni <<- "Bezva" # musíme použít <<-, aby se přiřadilo do proměnné vně této funkce
            
            # nová náhodná otázka
            radek <- sample(1: nrow(tab), size = 1) # zde pomocí <- vytváříme lokální proměnnou, ale to vůbec nevadí, protože v jiných funkcích s ní už dále neoperujeme
            rv$otazka <<- tab$otázka[radek]
            spravnaOdpoved <<- tab$odpověď[radek]
            
            updateTextInput(session = session, "odpoved", value = "") # smažeme textový vstup - není povinné, ale působí to příjemně :-)
            
        } else {  # netrefil se
            rv$hodnoceni <<- "Těsně vedle."
        }
    })

   
    output$zadani <- renderText({
        return(rv$otazka)
    })
    
    output$vyhodnoceni <- renderText({
        return(rv$hodnoceni)
    })
    
}

# Run the application 
shinyApp(ui = ui, server = server)
