library(shiny)

ui <- fluidPage(

    titlePanel("Vyjmenovaná slova"),

    sidebarLayout(
        sidebarPanel(
            actionButton("vstupI", "i / í"),
            actionButton("vstupY", "y / ý")
        ),

        mainPanel(
           textOutput("vystup")
        )
    )
)

tabulka <- read.table("vyjmenovana_slova.txt", header = TRUE, sep = "\t", fileEncoding = "UTF-8-BOM")


server <- function(input, output) {
  rv <- reactiveValues()
  rv$vyhodnoceni <- ""
  rv$cisloOtazky <- sample(1:nrow(tabulka), size = 1)
  
  pocatecniSpusteni <- TRUE # Protože při startu aplikace se vždy jakoby "stisknou všechna tlačítka",
                            # tak ať ještě nevyhodnocujeme odpověď
  
  observe({
    input$vstupI
    
    if (tabulka$odpověď[isolate(rv$cisloOtazky)] %in% c("i", "í")) {
      rv$cisloOtazky <<- sample(1:nrow(tabulka), size = 1)
      rv$vyhodnoceni <<- "ok"
    } else {
      rv$vyhodnoceni <<- "ne"
    }
  })
  
  observe({
    input$vstupY
    
    if (tabulka$odpověď[isolate(rv$cisloOtazky)] %in% c("y", "ý")) {
      rv$cisloOtazky <<- sample(1:nrow(tabulka), size = 1)
      rv$vyhodnoceni <<- "ok"
    } else {
      rv$vyhodnoceni <<- "ne"
    }
  })
  
  output$vystup <- renderText({
    if (!pocatecniSpusteni & rv$vyhodnoceni == "ok") {
      return(paste0("Správně! Nová úloha: ", tabulka$otázka[rv$cisloOtazky]))
    } else if (!pocatecniSpusteni & rv$vyhodnoceni == "ne") {
      return(paste0("Zkuste to znovu. Úloha: ", tabulka$otázka[rv$cisloOtazky]))
    } else {
      pocatecniSpusteni <<- FALSE
      return(paste0(tabulka$otázka[rv$cisloOtazky]))
    }
    
  })
}

# Run the application 
shinyApp(ui = ui, server = server)
